@@ -6,7 +6,7 @@ import os
 import re
 import sys
 
-DOCDIR = '/mondo/local/pygtk/share/gtk-doc/html/pygobject'
+DOCDIR = '${prefix}/share/gtk-doc/html/pygobject'
 
 anchors = {}
 anchor_pat = re.compile(r'''^\s*<ANCHOR\s+id\s*=\s*"([^"]*)"\s+
